import time
import cv2
class FPS:
    def __init__(self):
        self.ptime = time.time()
        self.frame_count = 0
    def showfps(self, display=None, writetext=True, text_pos=(10, 70),
               Fstyle =cv2.FONT_HERSHEY_COMPLEX ,
               tcolor=(255, 0, 0),
               fscale=1,fthickness=2,Sverbose=True):
        self.frame_count += 1
        cTime = time.time()
        fps = 1 / (cTime - self.ptime)
        self.ptime = cTime
        if Sverbose:
            print(f"FPS: {fps:.2f}")
        if writetext and display is not None:
            cv2.putText(display, f"FPS: {int(fps)}", 
                        text_pos,Fstyle, fscale, 
                        tcolor, fthickness)
        return fps
def main():
    fps_counter = FPS()
    cap = cv2.VideoCapture(0)
    while True:
        ret, frame = cap.read()
        if not ret:
            break
        fps = fps_counter.showfps(frame, writetext=True, text_pos=(10, 50),
                                fthickness=2,tcolor=(0,255,250),
                                Fstyle=cv2.FONT_HERSHEY_DUPLEX,fscale=2,)
        cv2.imshow('Frame', frame)
        if cv2.waitKey(1) & 0xFF == ord('q'):
            break
    cap.release()
    cv2.destroyAllWindows()
if __name__ == '__main__':
    main()



import cv2
import mediapipe as mp
import time
import math

class HandStar:
    def __init__(self, mode=False, maxHands=2, detectioncon=0.5, trackcon=0.5):
        self.mode = mode
        self.maxHands = maxHands
        self.detectioncon = detectioncon
        self.trackcon = trackcon

        self.mpHands = mp.solutions.hands
        self.hands = self.mpHands.Hands(static_image_mode=self.mode,
                                        max_num_hands=self.maxHands,
                                        min_detection_confidence=self.detectioncon,
                                        min_tracking_confidence=self.trackcon)
        self.mpDraw = mp.solutions.drawing_utils
        self.tipIds = [4, 8, 12, 16, 20]

    def detect_hands(self, img, draw=True,flip=True):
        if flip:
            img = cv2.flip(img, 1)
        imgrgb = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.hands.process(imgrgb)
        if self.results.multi_hand_landmarks:
            for handLms in self.results.multi_hand_landmarks:
                if draw:
                    self.mpDraw.draw_landmarks(img, handLms, self.mpHands.HAND_CONNECTIONS)
        return img

    def get_hand_positions(self, img, draw=True):
        self.lmList = []
        self.handTypes = []
        if self.results.multi_hand_landmarks:
            for handNo, handLms in enumerate(self.results.multi_hand_landmarks):
                handLmList = []
                for id, lm in enumerate(handLms.landmark):
                    h, w, c = img.shape
                    cx, cy = int(lm.x * w), int(lm.y * h)
                    handLmList.append([id, cx, cy])
                self.lmList.append(handLmList)
                if self.results.multi_handedness:
                    handType = self.results.multi_handedness[handNo].classification[0].label
                    self.handTypes.append(handType)
                    if draw and handLmList:
                        x_min = min([point[1] for point in handLmList])
                        y_min = min([point[2] for point in handLmList])
                        x_max = max([point[1] for point in handLmList])
                        y_max = max([point[2] for point in handLmList])
                        cv2.rectangle(img, (x_min - 20, y_min - 20), (x_max + 20, y_max + 20), (0, 255, 0), 2)
                        cv2.putText(img, handType, (x_min - 30, y_min - 30), cv2.FONT_HERSHEY_SIMPLEX, 1, (0, 255, 0), 2)
        return self.lmList

    def get_fingers_status(self):
        fingersList = []
        for handLmList in self.lmList:
            fingers = []
            if len(handLmList) == 0:
                fingersList.append(fingers)
                continue

            # Thumb
            if self.handTypes[self.lmList.index(handLmList)] == "Right":
                if handLmList[self.tipIds[0]][1] < handLmList[self.tipIds[0] - 1][1]:
                    fingers.append(1)
                else:
                    fingers.append(0)
            else:  # Left hand
                if handLmList[self.tipIds[0]][1] > handLmList[self.tipIds[0] - 1][1]:
                    fingers.append(1)
                else:
                    fingers.append(0)

            # Fingers
            for id in range(1, 5):
                if handLmList[self.tipIds[id]][2] < handLmList[self.tipIds[id] - 2][2]:
                    fingers.append(1)
                else:
                    fingers.append(0)
            fingersList.append(fingers)
        return fingersList

    def calculate_distance(self, p1, p2, img, handNo=0, draw=True):
        if len(self.lmList) == 0 or handNo >= len(self.lmList):
            return 0, img, []

        handLmList = self.lmList[handNo]
        x1, y1 = handLmList[p1][1], handLmList[p1][2]
        x2, y2 = handLmList[p2][1], handLmList[p2][2]
        cx, cy = (x1 + x2) // 2, (y1 + y2) // 2
        if draw:
            cv2.circle(img, (x1, y1), 15, (255, 0, 255), cv2.FILLED)
            cv2.circle(img, (x2, y2), 15, (255, 0, 255), cv2.FILLED)
            cv2.line(img, (x1, y1), (x2, y2), (255, 0, 255), 3)
            cv2.circle(img, (cx, cy), 15, (255, 0, 255), cv2.FILLED)

        length = math.hypot(x2 - x1, y2 - y1)
        return length, img, [x1, y1, x2, y2, cx, cy]

def main():
    cap = cv2.VideoCapture(0)
    detector = HandStar(maxHands=2)
    while True:
        success, img = cap.read()
        if not success:
            break
        img = detector.detect_hands(img)
        lmList = detector.get_hand_positions(img)
        if len(lmList) != 0:
            fingersList = detector.get_fingers_status()
            for i, fingers in enumerate(fingersList):
                length, img, lineInfo = detector.calculate_distance(4, 8, img, handNo=i)
        cv2.imshow('Image', img)
        if cv2.waitKey(1) == ord('q'):
            break
    cap.release()
    cv2.destroyAllWindows()

if __name__ == '__main__':
    main()




import cv2
import numpy as np
import requests

class Helper:
    def __init__(self):
        self.color_dict = {
            'red': (0, 0, 255),
            'green': (0, 255, 0),
            'blue': (255, 0, 0),
            'black': (0, 0, 0),
            'white': (255, 255, 255),
            'yellow': (0, 255, 255),
            'cyan': (255, 255, 0),
            'magenta': (255, 0, 255),
            'gray': (128, 128, 128),
            'light_gray': (211, 211, 211),
            'dark_gray': (169, 169, 169),
            'orange': (0, 165, 255),
            'pink': (203, 192, 255),
            'purple': (128, 0, 128),
            'brown': (42, 42, 165),
            'lime': (0, 255, 0),
            'gold': (0, 215, 255),
            'silver': (192, 192, 192),
            'navy': (128, 0, 0),
            'teal': (128, 128, 0)
        }

        self.font_dict = {
            'hershey_simplex': cv2.FONT_HERSHEY_SIMPLEX,
            'hershey_plain': cv2.FONT_HERSHEY_PLAIN,
            'hershey_duplex': cv2.FONT_HERSHEY_DUPLEX,
            'hershey_complex': cv2.FONT_HERSHEY_COMPLEX,
            'hershey_triplex': cv2.FONT_HERSHEY_TRIPLEX,
            'hershey_complex_small': cv2.FONT_HERSHEY_COMPLEX_SMALL,
            'hershey_script_simplex': cv2.FONT_HERSHEY_SCRIPT_SIMPLEX,
            'hershey_script_complex': cv2.FONT_HERSHEY_SCRIPT_COMPLEX,
            'italic': cv2.FONT_ITALIC,
            'hershey_simplex_bold': cv2.FONT_HERSHEY_SIMPLEX | cv2.FONT_ITALIC,
            'hershey_plain_bold': cv2.FONT_HERSHEY_PLAIN | cv2.FONT_ITALIC
        }

    def download_image_from_url(self, url):
        response = requests.get(url)
        image = np.array(bytearray(response.content), dtype=np.uint8)
        image = cv2.imdecode(image, cv2.IMREAD_COLOR)
        if image is None:
            raise ValueError("Error decoding the image from the URL.")
        return image

    def make_background_black(self, image):
        if image.shape[2] == 4:
            image = cv2.cvtColor(image, cv2.COLOR_BGRA2BGR)
        black = np.zeros_like(image)
        black[:] = 0
        return black

    def rotate_image(self, image, angle):
        (h, w) = image.shape[:2]
        (cX, cY) = (w // 2, h // 2)
        M = cv2.getRotationMatrix2D((cX, cY), angle, 1.0)
        cos = np.abs(M[0, 0])
        sin = np.abs(M[0, 1])
        nW = int((h * sin) + (w * cos))
        nH = int((h * cos) + (w * sin))
        M[0, 2] += (nW / 2) - cX
        M[1, 2] += (nH / 2) - cY
        return cv2.warpAffine(image, M, (nW, nH))

    def resize_to_same_height(self, img1, img2):
        h1, w1 = img1.shape[:2]
        h2, w2 = img2.shape[:2]
        if h1 != h2:
            new_w = int(w2 * (h1 / h2))
            img2 = cv2.resize(img2, (new_w, h1))
        return img1, img2

    def resize_to_same_width(self, img1, img2):
        h1, w1 = img1.shape[:2]
        h2, w2 = img2.shape[:2]
        if w1 != w2:
            new_h = int(h2 * (w1 / w2))
            img2 = cv2.resize(img2, (w1, new_h))
        return img1, img2

    def hstack_images(self, img1, img2):
        img1, img2 = self.resize_to_same_height(img1, img2)
        return np.hstack((img1, img2))

    def vstack_images(self, img1, img2):
        img1, img2 = self.resize_to_same_width(img1, img2)
        return np.vstack((img1, img2))

    def detect_color(self, image, color_name):
        if color_name in self.color_dict:
            lower_bound, upper_bound = self.get_color_bounds(color_name)
            hsv = cv2.cvtColor(image, cv2.COLOR_BGR2HSV)
            mask = cv2.inRange(hsv, lower_bound, upper_bound)
            return mask
        else:
            raise ValueError(f"Color {color_name} not found in color dictionary.")

    def get_color_bounds(self, color_name):
        color_ranges = {
            'red': [(0, 50, 50), (10, 255, 255)],
            'green': [(36, 25, 25), (70, 255, 255)],
            'blue': [(94, 80, 2), (126, 255, 255)],
            'yellow': [(22, 93, 0), (45, 255, 255)],
            'cyan': [(78, 158, 124), (138, 255, 255)],
            'magenta': [(125, 50, 50), (175, 255, 255)],
            'white': [(0, 0, 200), (180, 20, 255)],
            'gray': [(0, 0, 40), (180, 20, 200)],
            'black': [(0, 0, 0), (180, 255, 30)],
            'orange': [(10, 100, 20), (25, 255, 255)],
            'pink': [(160, 50, 50), (180, 255, 255)],
            'purple': [(129, 50, 70), (158, 255, 255)],
            'brown': [(10, 100, 20), (20, 255, 200)],
            'lime': [(29, 86, 6), (64, 255, 255)],
            'gold': [(24, 100, 100), (32, 255, 255)],
            'silver': [(0, 0, 192), (180, 18, 255)],
            'navy': [(100, 100, 50), (140, 255, 255)],
            'teal': [(85, 50, 50), (100, 255, 255)]
        }
        return color_ranges.get(color_name, [(0, 0, 0), (0, 0, 0)])

    def detect_corners(self, image, block_size=2, ksize=3, k=0.04):
        gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)
        corners = cv2.cornerHarris(gray, block_size, ksize, k)
        corners = cv2.dilate(corners, None)
        image[corners > 0.01 * corners.max()] = [0, 0, 255] 
        return image

    def add_text(self, image, text, position, font_name='hershey_simplex', font_scale=1, color_name='white', thickness=2, align='left'):
        color = self.color_dict.get(color_name, (255, 255, 255))
        font = self.font_dict.get(font_name, cv2.FONT_HERSHEY_SIMPLEX)
        (text_width, text_height), baseline = cv2.getTextSize(text, font, font_scale, thickness)
        if align == 'center':
            position = (position[0] - text_width // 2, position[1] + text_height // 2)
        elif align == 'right':
            position = (position[0] - text_width, position[1] + text_height // 2)
        elif align == 'left':
            position = (position[0], position[1] + text_height // 2)
        
        return cv2.putText(image, text, position, font, font_scale, color, thickness)

# Usage
def main():
    utils = Helper()
    image_url = 'https://image.shutterstock.com/image-vector/dotted-spiral-vortex-royaltyfree-images-600w-2227567913.jpg'  # Replace with the actual image URL
    image = utils.download_image_from_url(image_url)
    black_background_image = utils.make_background_black(image)
    rotated_image = utils.rotate_image(image, 45)
    img2 = cv2.imread('med/ig.jpg')  
    hstacked_image = utils.hstack_images(image, img2)
    vstacked_image = utils.vstack_images(image, img2)
    detected_color = utils.detect_color(image, 'green')
    image_with_corners = utils.detect_corners(image)
    image_with_text_left = utils.add_text(image, 'Hello World', (50, 50), font_name='hershey_triplex', color_name='blue', align='left')
    cv2.waitKey(0)
    cv2.destroyAllWindows()
if __name__ == "__main__":
    main()


import cv2
import mediapipe as mp 
import time
import math

class PoseDetector:
    def __init__(self, mode=False, smooth=True, detectionCon=0.5, trackCon=0.5, flip=True):
        self.mode = mode
        self.smooth = smooth
        self.flip = flip
        self.detectionCon = detectionCon
        self.trackCon = trackCon

        self.mpPose = mp.solutions.pose
        self.mpDraw = mp.solutions.drawing_utils
        self.pose = self.mpPose.Pose(static_image_mode=self.mode, 
                                     smooth_landmarks=self.smooth, 
                                     min_detection_confidence=self.detectionCon, 
                                     min_tracking_confidence=self.trackCon)

    def findPose(self, img, draw=True):
        if self.flip:
            img = cv2.flip(img, 1)
        imgRGB = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.pose.process(imgRGB)
        if self.results.pose_landmarks:
            if draw:
                self.mpDraw.draw_landmarks(img, self.results.pose_landmarks, self.mpPose.POSE_CONNECTIONS)
        return img

    def findPosition(self, img, draw=True):
        if self.flip:
            img = cv2.flip(img, 1)
        self.lmList = []
        if self.results.pose_landmarks:
            for id, lm in enumerate(self.results.pose_landmarks.landmark):
                h, w, c = img.shape
                cx, cy = int(lm.x * w), int(lm.y * h)
                self.lmList.append([id, cx, cy])
                if draw:
                    cv2.circle(img, (cx, cy), 10, (0, 255, 0), cv2.FILLED)
        return self.lmList

    def findAngle(self, img, p1, p2, p3, draw=True, anglewrite=True):
        if len(self.lmList) != 0:
            _, x1, y1 = self.lmList[p1]
            _, x2, y2 = self.lmList[p2]
            _, x3, y3 = self.lmList[p3]
            angle = math.degrees(math.atan2(y3 - y2, x3 - x2) - math.atan2(y1 - y2, x1 - x2))
            if angle < 0:
                angle += 360
            if anglewrite:
                cv2.putText(img, str(int(angle)), (x2 - 100, y2 + 100), cv2.FONT_HERSHEY_DUPLEX, 2, (255, 0, 255), 2)
            if draw:
                cv2.line(img, (x1, y1), (x2, y2), (255, 255, 255), 3)
                cv2.line(img, (x3, y3), (x2, y2), (255, 255, 255), 3)
                cv2.circle(img, (x1, y1), 10, (0, 255, 0), cv2.FILLED)
                cv2.circle(img, (x1, y1), 15, (0, 255, 0), 2)
                cv2.circle(img, (x2, y2), 10, (0, 255, 0), cv2.FILLED)
                cv2.circle(img, (x2, y2), 15, (0, 255, 0), 2)
                cv2.circle(img, (x3, y3), 10, (0, 255, 0), cv2.FILLED)
                cv2.circle(img, (x3, y3), 15, (0, 255, 0), 2)
        return angle

    def findDistance(self, p1, p2, img=None, color=(255, 0, 255), scale=5):
        x1, y1 = p1
        x2, y2 = p2
        cx, cy = (x1 + x2) // 2, (y1 + y2) // 2
        length = math.hypot(x2 - x1, y2 - y1)
        info = (x1, y1, x2, y2, cx, cy)

        if img is not None:
            cv2.line(img, (x1, y1), (x2, y2), color, max(1, scale // 3))
            cv2.circle(img, (x1, y1), scale, color, cv2.FILLED)
            cv2.circle(img, (x2, y2), scale, color, cv2.FILLED)
            cv2.circle(img, (cx, cy), scale, color, cv2.FILLED)

        return length, img, info
    
def main():
    cap = cv2.VideoCapture(0)
    detector = PoseDetector()
    while True:
        success, img = cap.read()
        img = cv2.resize(img, (680, 680))
        img = detector.findPose(img)
        lmList = detector.findPosition(img)
        if lmList:
            cv2.circle(img, (lmList[14][1], lmList[14][2]), 10, (250, 0, 0), cv2.FILLED)
            length, img, info = detector.findDistance(lmList[11][1:3], lmList[15][1:3], img=img, color=(255, 0, 0), scale=10)
        cv2.imshow("image", img)
        if cv2.waitKey(1) == ord('q'):
            break

if __name__ == '__main__':
    main()



import cv2
import mediapipe as mp
import time
import math

class FaceDetector:
    def __init__(self, min_detection_confidence=0.5, static_mode=False, max_faces=2, min_tracking_confidence=0.5,flip=True):
        self.min_detection_confidence = min_detection_confidence
        self.static_mode = static_mode
        self.max_faces = max_faces
        self.flip = flip
        self.min_tracking_confidence = min_tracking_confidence

        self.mp_face_detection = mp.solutions.face_detection
        self.face_detection = self.mp_face_detection.FaceDetection(min_detection_confidence=self.min_detection_confidence)
        
        self.mp_draw = mp.solutions.drawing_utils
        self.mp_face_mesh = mp.solutions.face_mesh
        self.face_mesh = self.mp_face_mesh.FaceMesh(static_image_mode=self.static_mode, 
                                                    max_num_faces=self.max_faces, 
                                                    min_detection_confidence=self.min_detection_confidence, 
                                                    min_tracking_confidence=self.min_tracking_confidence)
        self.draw_spec = self.mp_draw.DrawingSpec(thickness=2, circle_radius=2)

    def find_faces(self, img, draw=True):
        img_rgb = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        if self.flip:
            img = cv2.flip(img,1)
        self.results = self.face_detection.process(img_rgb)
        bboxs = []
        if self.results.detections:
            for id, detection in enumerate(self.results.detections):
                bboxC = detection.location_data.relative_bounding_box
                ih, iw, ic = img.shape
                bbox = int(bboxC.xmin * iw), int(bboxC.ymin * ih), \
                       int(bboxC.width * iw), int(bboxC.height * ih)
                bboxs.append([id, bbox, detection.score])
                if draw:
                    img = self.imp_draw(img, bbox)
                    cv2.putText(img, f'{int(detection.score[0] * 100)}%', (bbox[0], bbox[1] - 20), cv2.FONT_HERSHEY_COMPLEX, 1, (255, 0, 250), 2)
        return img, bboxs

    def imp_draw(self, img, bbox, l=30, t=10, rt=1): #it is to make square near face
        x, y, w, h = bbox
        x1, y1 = x + w, y + h
        cv2.rectangle(img, bbox, (255, 0, 0), rt)
        # Top left
        cv2.line(img, (x, y), (x + l, y), (255, 255, 0), 2)
        cv2.line(img, (x, y), (x, y + l), (255, 255, 0), 2)
        # Top right
        cv2.line(img, (x1, y), (x1 - l, y), (255, 255, 0), 2)
        cv2.line(img, (x1, y), (x1, y + l), (255, 255, 0), 2)
        # Bottom left
        cv2.line(img, (x, y1), (x + l, y1), (255, 255, 0), 2)
        cv2.line(img, (x, y1), (x, y1 - l), (255, 255, 0), 2)
        # Bottom right
        cv2.line(img, (x1, y1), (x1 - l, y1), (255, 255, 0), 2)
        cv2.line(img, (x1, y1), (x1, y1 - l), (255, 255, 0), 2)
        return img

    def find_face_mesh(self, img, meshdraw=True,pointdraw=True):
        if self.flip:
            img = cv2.flip(img,1)
        img_rgb = cv2.cvtColor(img, cv2.COLOR_BGR2RGB)
        self.results = self.face_mesh.process(img_rgb)
        faces = []
        if self.results.multi_face_landmarks:
            for faceLms in self.results.multi_face_landmarks:
                if meshdraw:
                    self.mp_draw.draw_landmarks(img, faceLms, self.mp_face_mesh.FACEMESH_CONTOURS,
                                           self.draw_spec, self.draw_spec)
                face = []
                for id, lm in enumerate(faceLms.landmark):
                    ih, iw, ic = img.shape
                    x, y = int(lm.x * iw), int(lm.y * ih)
                    # cv2.putText(img, str(id),(x,y), cv2.FONT_HERSHEY_COMPLEX, 0.7, (255, 0, 0), 1)
                    # print(id, x, y)
                    face.append([x, y])
                faces.append(face)
                #These are some main points using which we can work
                facial_landmarks = {
                'left_eye': [33, 133, 160, 159, 158, 157, 173, 153, 144, 163, 7, 246, 161, 160, 159, 158],
                'right_eye': [362, 382, 381, 380, 374, 373, 390, 249, 263, 466, 388, 387, 386, 385, 384, 398],
                'left_eyebrow': [70, 63, 105, 66, 107, 55, 193],
                'right_eyebrow': [336, 296, 334, 293, 300, 276, 283],
                'nose':[1, 2, 5, 4, 98, 97, 2, 327, 326, 193, 209, 198, 217, 275, 363, 456, 419, 331, 274, 275, 195, 193],
                'mouth': [61, 146, 91, 181, 84, 17, 314, 405, 321, 375, 291, 308, 324, 318, 402, 317, 14, 87, 178, 88, 61, 185, 40, 39, 37, 0, 267, 269, 270, 409, 291],
                'forehead': [10, 338, 297, 332, 284, 251, 389, 361, 454, 323, 361, 355, 368, 264, 447, 386, 374, 373, 10, 109, 67, 103, 54, 21, 162, 127, 234, 93, 132, 58, 172, 136, 150, 176, 148, 152, 377, 400, 378, 379, 397, 288]}           
                # Colors for each part
                colors = {
                    'left_eye': (0, 255, 0),
                    'right_eye': (255, 0, 0),
                    'left_eyebrow': (0, 255, 255),
                    'right_eyebrow': (255, 255, 0),
                    'nose': (255, 0, 255),
                    'mouth': (0, 0, 255),
                    'forehead': (128, 0, 128),
                }
                if pointdraw:
                    if len(faces) != 0:
                        for face in faces:
                            for part, points in facial_landmarks.items():
                                for point in points:
                                    coord = face[point]
                                    cv2.circle(img, (coord[0], coord[1]), 3, colors[part], cv2.FILLED)
                                    cv2.putText(img, str(point), (coord[0], coord[1]), cv2.FONT_HERSHEY_SIMPLEX, 0.3, (255, 255, 255), 1)
        return img, faces
    def findDistance(self,p1, p2, img=None):
        x1, y1 = p1
        x2, y2 = p2
        cx, cy = (x1 + x2) // 2, (y1 + y2) // 2
        length = math.hypot(x2 - x1, y2 - y1)
        info = (x1, y1, x2, y2, cx, cy)
        if img is not None:
            cv2.circle(img, (x1, y1), 15, (255, 0, 255), cv2.FILLED)
            cv2.circle(img, (x2, y2), 15, (255, 0, 255), cv2.FILLED)
            cv2.line(img, (x1, y1), (x2, y2), (255, 0, 255), 3)
            cv2.circle(img, (cx, cy), 15, (255, 0, 255), cv2.FILLED)
            return length,info, img
        else:
            return length, info

def main():
    cap = cv2.VideoCapture(0)
    detector = FaceDetector()

    while True:
        success, img = cap.read()
        if not success:
            break

        # Detect faces and draw bounding boxes using imp_draw
        img, bboxs = detector.find_faces(img)
        if bboxs:
            # Draw styled bounding boxes using imp_draw
            for _, bbox, _ in bboxs:
                img = detector.imp_draw(img, bbox)
            print("Bounding boxes:", bboxs)

        # Detect face mesh and draw landmarks
        img, faces = detector.find_face_mesh(img)
        if faces:
            print(f"Number of faces detected: {len(faces)}")

            # Example of finding distance between two landmarks for the first face detected
            p1 = faces[0][33]  # Example: left eye landmark
            p2 = faces[0][263] # Example: right eye landmark
            length, info, img = detector.findDistance(p1, p2, img)
            print(f"Distance between points: {length}, Info: {info}")

        # Display the resulting frame
        cv2.imshow('Image', img)

        # Exit the loop when 'q' is pressed
        if cv2.waitKey(1) & 0xFF == ord('q'):
            break

    cap.release()
    cv2.destroyAllWindows()

if __name__ == '__main__':
    main()




from setuptools import setup, find_packages
setup(
    name='Kazier',
    version='0.0.1',
    packages=find_packages(),
    author='Sumit Kumar Singh',
    author_email='sumitsingh9441@gmail.com',
    description='A comprehensive package for face detection, hand tracking, pose estimation, and more using MediaPipe, designed to simplify your project development.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/RAJPUTRoCkStAr/Kazier.git',
     keywords=[
        'computer vision', 
        'mediapipe', 
        'face detection', 
        'hand tracking', 
        'pose estimation', 
        'opencv', 
        'image processing', 
        'machine learning', 
        'AI', 
        'artificial intelligence'
    ],
    install_requires=[
        'numpy','opencv-python','mediapipe','requests'
    ],
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
)